@@ -5,4 +5,4 @@ from . import cythonmodule
 from .utils import OutOfRangeException, UnequalLengthException, InvalidQuantumStateException
 from .schmidt import schmidt_decomposition
 from .continuous import continuous_schmidt_decomposition
-from .metrics import entanglement_entropy, participation_ratio, negativity, concurrence
+from .metrics import entanglement_entropy, participation_ratio, negativity, concurrence, renyi_entanglement_entropy
